@@ -23,7 +23,7 @@
 #define TMPDIR                 "/tmp"
 #define VAR_TMPDIR             "/var/tmp"
 #define PORTAGE_TMPDIR         "/var/tmp/portage"
-#define PIDS_FILE              "/sandboxpids.tmp"
+#define SANDBOX_LOG_LOCATION   "/var/log/sandbox"
 #define LOG_FILE_PREFIX        "/sandbox-"
 #define DEBUG_LOG_FILE_PREFIX  "/sandbox-debug-"
 #define LOG_FILE_EXT           ".log"
@@ -33,11 +33,10 @@
 #define ENV_TMPDIR             "TMPDIR"
 #define ENV_PORTAGE_TMPDIR     "PORTAGE_TMPDIR"
 
-#define ENV_SANDBOX_DEBUG_LOG  "SANDBOX_DEBUG_LOG"
-#define ENV_SANDBOX_LOG        "SANDBOX_LOG"
-#define ENV_SANDBOX_DIR        "SANDBOX_DIR"
 #define ENV_SANDBOX_LIB        "SANDBOX_LIB"
 #define ENV_SANDBOX_BASHRC     "SANDBOX_BASHRC"
+#define ENV_SANDBOX_LOG        "SANDBOX_LOG"
+#define ENV_SANDBOX_DEBUG_LOG  "SANDBOX_DEBUG_LOG"
 
 #define ENV_SANDBOX_DENY       "SANDBOX_DENY"
 #define ENV_SANDBOX_READ       "SANDBOX_READ"
@@ -55,24 +54,49 @@
 # define dlvsym(lib, sym, ver) dlsym(lib, sym)
 #endif
 
-SB_STATIC char *get_sandbox_path(char *argv0);
-SB_STATIC char *get_sandbox_lib(char *sb_path);
-SB_STATIC char *get_sandbox_pids_file(const char *tmp_dir);
-SB_STATIC char *get_sandbox_rc(char *sb_path);
-SB_STATIC char *get_sandbox_log(const char *tmp_dir);
-SB_STATIC char *get_sandbox_debug_log(const char *tmp_dir);
-SB_STATIC int get_tmp_dir(char *tmp_dir);
-SB_STATIC char *sb_dirname(const char *path);
-SB_STATIC int file_getmode(char *mode);
-SB_STATIC long file_tell(int fp);
-SB_STATIC int file_lock(int fd, int lock, char *filename);
-SB_STATIC int file_unlock(int fd);
-SB_STATIC int file_locktype(char *mode);
-SB_STATIC int file_open(char *filename, char *mode, int perm_specified, ...);
-SB_STATIC void file_close(int fd);
+/* Gentoo style e* printing macro's */
+#define EINFO(_color, _hilight, _args...) \
+	do { \
+		int old_errno = errno; \
+		if (_color) \
+			printf("\033[32;01m" _hilight "\033[0m" _args); \
+		else \
+			printf(_hilight _args); \
+		errno = old_errno; \
+	} while (0)
+
+#define EWARN(_color, _hilight, _args...) \
+	do { \
+		int old_errno = errno; \
+		if (_color) \
+			printf("\033[33;01m" _hilight "\033[0m" _args); \
+		else \
+			printf(_hilight _args); \
+		errno = old_errno; \
+	} while (0)
+
+#define EERROR(_color, _hilight, _args...) \
+	do { \
+		int old_errno = errno; \
+		if (_color) \
+			fprintf(stderr, "\033[31;01m" _hilight "\033[0m" _args); \
+		else \
+			fprintf(stderr, _hilight _args); \
+		errno = old_errno; \
+	} while (0)
+
+SB_STATIC void get_sandbox_lib(char *path);
+#ifdef OUTSIDE_LIBSANDBOX
+SB_STATIC void get_sandbox_rc(char *path);
+SB_STATIC void get_sandbox_log(char *path);
+SB_STATIC void get_sandbox_debug_log(char *path);
+SB_STATIC int get_tmp_dir(char *path);
+#endif /* OUTSIDE_LIBSANDBOX */
+SB_STATIC int exists(const char *pathname);
+#ifdef OUTSIDE_LIBSANDBOX
+SB_STATIC int is_file(const char *pathname);
 SB_STATIC long file_length(int fd);
-SB_STATIC int file_truncate(int fd);
-SB_STATIC int file_exist(char *filename, int checkmode);
+#endif /* OUTSIDE_LIBSANDBOX */
 
 #endif
 
